unit Setup1;
{
This is a template of generic install -- please change it if you
so desire.  Just remember to adjust the components for any
changes you make -- and don't forget to test the install.  There
are several steps that will need to take if you want to use this
generic install:

1) Select the files you want to install by double clicking on the
   suInfo component.  Also build any sort of directory structure
   you desire by editing the directories.  Don't forget to set
   the disk type as well. Don't forget to compile your program so
   that you can add its executable to the list of files.

   NOTE: If doing a multi-disk install or using the uninstall,
         you must copy STUBBER.EXE into the same dir as the
         setup/uninstall program.

2) Name the application by changing the AppName property in the
   suInfo component.  Also, set the Picture property to some
   bitmap that you would like to use -- or just use the default.
   Don't forget to name your application under Options|Project.

3) Customize the message in the suWelcome component by double
   clicking on it.

4) Customize the files installed (or removed) by the different
   options in the suInstallType component.  Do this by double
   clicking on it.  Notice that there are three types of
   installation types: COMPLETE, MINIMAL, CUSTOM.  NOTE: If
   adding options, don't forget to rewrite the
   suInstallTypeOnNextPage procedure.

5) Customize the options in suOptions.

6) Customize the TargetDir and Text properties in the suDir
   property.

7) Customize the text in the suPreCopy message by double clicking
   on it.

8) Customize the OverWrite property in the suCopy component.

9) Customize the program group name and items to be added by
   double clicking on the suGroups component.

   NOTE: If using the uninstall feature, you must add an icon
         to the program group for the setup/uninstall program.
         Don't forget to add the UNINSTALL parameter.

10) If you have a readme file, then change the properties in
    suProg so as to run the correct viewer ie NOTEPAD.EXE, then
    make the necessary changes to suGroupsNextPage procedure
    so that the correct file is being displayed.  Make sure
    the file was copied over.

11) If you want to addtional cleanup during the install,
    attach a handler to the OnCleanup event of the suUnInstall
    component.

12) Compile and run in Test mode (Test property in suInfo).

13) Compile and run in non-Test mode.  Try it from disk too.

These steps are generic.  Hope they help in building an install
for your application.

Jason Swager
jswager@activevoice.com
http://weber.u.washington.edu/~taime

}
interface

uses
  SysUtils, WinTypes, WinProcs, Messages, Classes, Graphics, Controls,
  Forms, Dialogs, TSetup, StdCtrls, ExtCtrls, TSetup_B, TSetup_A;

type
  TSetupForm = class(TForm)
    suInfo: TSetupInfo;
    suDir: TSetupDirChoice;
    suCopy: TSetupFileCopy;
    suGroups: TSetupGroups;
    suUnInstall: TSetupUnInstall;
    suWelcome: TSetupMessage;
    suInstallType: TSetupRadioChoice;
    suOptions: TSetupCheckBoxChoice;
    suPreFileCopy: TSetupMessage;
    suProg: TSetupProgExec;
    SetupBackground1: TSetupBackground;
    procedure FormCreate(Sender: TObject);
    procedure suGroupsNextPage(Sender: TObject);
    procedure suInstallTypeNextPage(Sender: TObject);
    procedure suUnInstallCleanup(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  SetupForm: TSetupForm;

implementation

{$R *.DFM}

uses FileCtrl, INIFiles;

const
  {This will be used to add information to the Add/Remove Programs
  dialog box.}
  ApplicationName = 'Sample TSetup Program';

procedure TSetupForm.FormCreate(Sender: TObject);
begin
  { Set the window's caption and application's title.}
  Caption:= suInfo.AppName + ' Setup Program';
  Application.Title:= Caption;
end;

procedure TSetupForm.suGroupsNextPage(Sender: TObject);
begin
  { See if a README.TXT file exists in the target directory.}
  if FileExists(suDir.TargetDir + 'README.TXT') then
  { Ask the user if the would like to see the readme file. }
    if MessageDlg('Would you like to read the README.TXT file?',
                  mtConfirmation, [mbYes, mbNo], 0) = mrYes then
      begin
        { First make sure the component is pointing to the right file }
        suProg.CommandLine:= suDir.TargetDir + 'README.TXT';
        { Display the file via NotePad }
        suProg.Execute;
      end;
  { If we made it this far, then add the uninstall information to
    the Add/Remove Programs dialog box -- NOTE This will only be
    noticed on Win95/WinNT4.0 platform. }
  suUnInstall.AddRegUnInstall(ApplicationName);
end;

procedure TSetupForm.suInstallTypeNextPage(Sender: TObject);
{ This will allow the user choose install options }
begin
  { If the user selected the CUSTOM install then present the
    options }
  if suInstallType.Selected[3] then suOptions.Execute;
end;

procedure TSetupForm.suUnInstallCleanup(Sender: TObject);
begin
  {Remove any information from the Add/Remove Programs dialog box.}
  suUnInstall.RemoveRegUnInstall(ApplicationName);
end;

end.
